changeset 48:83e9649a6606 1.1.7

Fixed Abyssal Seahorse mounting in certain subzones of Vashj'ir
author syzler
date Thu, 20 Sep 2012 01:28:44 -0400
parents bd6cb476e312
children d29ceeeab123
files MyLilPony.lua libMyLilPony/libMyLilPony_mountData.lua
diffstat 2 files changed, 5 insertions(+), 4 deletions(-) [+]
line wrap: on
line diff
--- a/libMyLilPony/libMyLilPony_mountData.lua	Wed Aug 29 00:50:34 2012 -0400
+++ b/libMyLilPony/libMyLilPony_mountData.lua	Thu Sep 20 01:28:44 2012 -0400
@@ -151,9 +151,9 @@
     return entry ~= nil and string.match(entry, "Q");
 end
 
---- Checks whether or not the specified spell ID is a Vash'jir mount.
+--- Checks whether or not the specified spell ID is a Vashj'ir mount.
 -- @param spellId The spell ID of the mount to be checked.
--- @return A Boolean value indicating whether or not the specified spell is a Vash'jir mount.
+-- @return A Boolean value indicating whether or not the specified spell is a Vashj'ir mount.
 function MyLilPony.IsVashjirMount(spellId)
     local entry = MyLilPony_Mounts[spellId];
     return entry ~= nil and string.match(entry, "V");
--- a/MyLilPony.lua	Wed Aug 29 00:50:34 2012 -0400
+++ b/MyLilPony.lua	Thu Sep 20 01:28:44 2012 -0400
@@ -90,9 +90,9 @@
         end
     end
     
-    -- player is swimming in Vash'jir
-    if IsSwimming() and (zone == "Shimmering Expanse" or zone == "Kelp'thar Forest" or zone == "Abyssal Depths") then
-        -- normal behaviour in Vash'jir is to call the Abyssal Seahorse
+    -- player is swimming in Vashj'ir
+    if IsSwimming() and (zone == "Shimmering Expanse" or zone == "Kelp'thar Forest" or zone == "Abyssal Depths" or zone == "Ruins of Vashj'ir" or zone == "Beth'mora Ridge" or zone == "The Undershell") then
+        -- normal behaviour in Vashj'ir is to call the Abyssal Seahorse
         -- modified behaviour is to attempt flight (i.e. you're at the surface)
         if not IsModifierKeyDown() and MyLilPony.CallMountByName("Abyssal Seahorse") then
             return;